==> nextcloud-20.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_status/l10n/gl.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Estados recentes",
    "In a meeting" : "Nunha xuntanza",
    "Commuting" : "De casa ao traballo ou ao revés",
    "Out sick" : "Enfermo",
    "Vacationing" : "De vacacións",
    "Working remotely" : "Traballando en remoto",
    "User status" : "Estado do usuario",
    "Clear status message after" : "Limpar a mensaxe de estado após",
    "What's your status?" : "Cal é o seu estado?",
    "Set status" : "Estabelecer o estado",
    "Online status" : "Estado en liña",
    "Status message" : "Mensaxe de estado",
    "Clear status message" : "Limpar a mensaxe de estado",
    "Set status message" : "Establecer a mensaxe de estado",
    "There was an error saving the status" : "Produciuse un erro ao gardar o estado",
    "There was an error clearing the status" : "Produciuse un erro ao limpar o estado",
    "No recent status changes" : "Non hai cambios de estado recentes",
    "Away" : "Ausente",
    "Do not disturb" : "Non molestar",
    "{status}, {timestamp}" : "{status} ás {timestamp}",
    "Don't clear" : "Non limpar",
    "Today" : "Hoxe",
    "This week" : "Esta semana",
    "Online" : "En liña",
    "Invisible" : "Invisíbel",
    "Offline" : "Sen conexión",
    "There was an error saving the new status" : "Produciuse un erro ao gardar o novo estado",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 hora",
    "4 hours" : "4 horas",
    "Mute all notifications" : "Silenciar todas as notificacións",
    "Appear offline" : "Aparece coma sen conexión",
    "Clear status after" : "Limpar o estado após"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_status/l10n/gl.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Estados recentes",
    "In a meeting" : "Nunha xuntanza",
    "Commuting" : "De casa ao traballo ou ao revés",
    "Out sick" : "Enfermo",
    "Vacationing" : "De vacacións",
    "Working remotely" : "Traballando en remoto",
    "User status" : "Estado do usuario",
    "View profile" : "Ver o perfil",
    "Clear status after" : "Limpar o estado após",
    "What is your status?" : "Cal é o seu estado?",
    "Set status" : "Estabelecer o estado",
    "Online status" : "Estado en liña",
    "Status message" : "Mensaxe de estado",
    "Clear status message" : "Limpar a mensaxe de estado",
    "Set status message" : "Establecer a mensaxe de estado",
    "There was an error saving the status" : "Produciuse un erro ao gardar o estado",
    "There was an error clearing the status" : "Produciuse un erro ao limpar o estado",
    "No recent status changes" : "Non hai cambios de estado recentes",
    "Away" : "Ausente",
    "Do not disturb" : "Non molestar",
    "{status}, {timestamp}" : "{status} ás {timestamp}",
    "Don't clear" : "Non limpar",
    "Today" : "Hoxe",
    "This week" : "Esta semana",
    "Online" : "En liña",
    "Invisible" : "Invisíbel",
    "Offline" : "Sen conexión",
    "There was an error saving the new status" : "Produciuse un erro ao gardar o novo estado",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 hora",
    "4 hours" : "4 horas",
    "Mute all notifications" : "Silenciar todas as notificacións",
    "Appear offline" : "Aparece coma sen conexión",
    "Clear status message after" : "Limpar a mensaxe de estado após",
    "What's your status?" : "Cal é o seu estado?"
},
"nplurals=2; plural=(n != 1);");
